@@ -241,7 +241,7 @@ class Okular::FormFieldChoicePrivate : public Okular::FormFieldPrivate
         {
             Q_Q( const FormFieldChoice );
             QList<int> choices = q->currentChoices();
-            qSort( choices );
+            std::sort(choices.begin(), choices.end());
             QStringList list;
             foreach ( int c, choices )
             {
@@ -294,3 +294,32 @@ bool FormFieldChoice::canBeSpellChecked() const
     return false;
 }
 
+class Okular::FormFieldSignaturePrivate : public Okular::FormFieldPrivate
+{
+    public:
+        FormFieldSignaturePrivate()
+            : FormFieldPrivate( FormField::FormSignature )
+        {
+        }
+
+        Q_DECLARE_PUBLIC( FormFieldSignature )
+
+        void setValue( const QString& v ) override
+        {
+            Q_UNUSED( v )
+        }
+
+        QString value() const override
+        {
+            return QString();
+        }
+};
+
+FormFieldSignature::FormFieldSignature()
+    : FormField( *new FormFieldSignaturePrivate() )
+{
+}
+
+FormFieldSignature::~FormFieldSignature()
+{
+}
