@@ -28,6 +28,8 @@
 
 #include "document.h"
 
+#include <cmath>
+
 using namespace Okular;
 
 /**
@@ -165,24 +167,34 @@ void TextDocumentGeneratorPrivate::addMetaData( DocumentInfo::Key key, const QSt
     mDocumentInfo.set( key, value );
 }
 
-void TextDocumentGeneratorPrivate::generateLinkInfos()
+QList<TextDocumentGeneratorPrivate::LinkInfo> TextDocumentGeneratorPrivate::generateLinkInfos() const
 {
+    QList<LinkInfo> result;
+
     for ( int i = 0; i < mLinkPositions.count(); ++i ) {
         const LinkPosition &linkPosition = mLinkPositions[ i ];
 
-        LinkInfo info;
-        info.link = linkPosition.link;
+        const QVector<QRectF> rects = TextDocumentUtils::calculateBoundingRects( mDocument, linkPosition.startPosition, linkPosition.endPosition );
 
-        TextDocumentUtils::calculateBoundingRect( mDocument, linkPosition.startPosition, linkPosition.endPosition,
-                                                  info.boundingRect, info.page );
+        for ( int i = 0; i < rects.count(); ++i) {
+            const QRectF &rect = rects[ i ];
 
-        if ( info.page >= 0 )
-            mLinkInfos.append( info );
+            LinkInfo info;
+            info.link = linkPosition.link;
+            info.ownsLink = i == 0;
+            info.page = std::floor( rect.y() );
+            info.boundingRect = QRectF( rect.x(), rect.y() - info.page, rect.width(), rect.height() );
+            result.append( info );
+        }
     }
+
+    return result;
 }
 
-void TextDocumentGeneratorPrivate::generateAnnotationInfos()
+QList<TextDocumentGeneratorPrivate::AnnotationInfo> TextDocumentGeneratorPrivate::generateAnnotationInfos() const
 {
+    QList<AnnotationInfo> result;
+
     for ( int i = 0; i < mAnnotationPositions.count(); ++i ) {
         const AnnotationPosition &annotationPosition = mAnnotationPositions[ i ];
 
@@ -193,8 +205,10 @@ void TextDocumentGeneratorPrivate::generateAnnotationInfos()
                                                   info.boundingRect, info.page );
 
         if ( info.page >= 0 )
-            mAnnotationInfos.append( info );
+            result.append( info );
     }
+
+    return result;
 }
 
 void TextDocumentGeneratorPrivate::generateTitleInfos()
@@ -310,29 +324,31 @@ Document::OpenResult TextDocumentGenerator::loadDocumentWithPassword( const QStr
     d->mDocument = d->mConverter->document();
 
     d->generateTitleInfos();
-    d->generateLinkInfos();
-    d->generateAnnotationInfos();
+    const QList<TextDocumentGeneratorPrivate::LinkInfo> linkInfos = d->generateLinkInfos();
+    const QList<TextDocumentGeneratorPrivate::AnnotationInfo> annotationInfos = d->generateAnnotationInfos();
 
     pagesVector.resize( d->mDocument->pageCount() );
 
     const QSize size = d->mDocument->pageSize().toSize();
 
     QVector< QLinkedList<Okular::ObjectRect*> > objects( d->mDocument->pageCount() );
-    for ( int i = 0; i < d->mLinkInfos.count(); ++i ) {
-        const TextDocumentGeneratorPrivate::LinkInfo &info = d->mLinkInfos.at( i );
-
+    for ( const TextDocumentGeneratorPrivate::LinkInfo &info : linkInfos ) {
         // in case that the converter report bogus link info data, do not assert here
         if ( info.page >= objects.count() )
           continue;
 
         const QRectF rect = info.boundingRect;
-        objects[ info.page ].append( new Okular::ObjectRect( rect.left(), rect.top(), rect.right(), rect.bottom(), false,
-                                                             Okular::ObjectRect::Action, info.link ) );
+        if ( info.ownsLink ) {
+            objects[ info.page ].append( new Okular::ObjectRect( rect.left(), rect.top(), rect.right(), rect.bottom(), false,
+                                                                 Okular::ObjectRect::Action, info.link ) );
+        } else {
+            objects[ info.page ].append( new Okular::NonOwningObjectRect( rect.left(), rect.top(), rect.right(), rect.bottom(), false,
+                                                                          Okular::ObjectRect::Action, info.link ) );
+        }
     }
 
     QVector< QLinkedList<Okular::Annotation*> > annots( d->mDocument->pageCount() );
-    for ( int i = 0; i < d->mAnnotationInfos.count(); ++i ) {
-        const TextDocumentGeneratorPrivate::AnnotationInfo &info = d->mAnnotationInfos[ i ];
+    for ( const TextDocumentGeneratorPrivate::AnnotationInfo &info : annotationInfos ) {
         annots[ info.page ].append( info.annotation );
     }
 
@@ -360,9 +376,7 @@ bool TextDocumentGenerator::doCloseDocument()
 
     d->mTitlePositions.clear();
     d->mLinkPositions.clear();
-    d->mLinkInfos.clear();
     d->mAnnotationPositions.clear();
-    d->mAnnotationInfos.clear();
     // do not use clear() for the following two, otherwise they change type
     d->mDocumentInfo = Okular::DocumentInfo();
     d->mDocumentSynopsis = Okular::DocumentSynopsis();
