@@ -17,13 +17,14 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */
 
+#include "faxexpand.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <sys/types.h>
 
-#include <QtCore/QDebug>
+#include <QDebug>
 
-#include "faxexpand.h"
 #include "fax_debug.h"
 //Uncomment this for verbose debug output
 //#define DEBUG_FAX
